@@ -124,9 +124,10 @@ class powerswitch:
         """ Cycle power to an outlet 
             False = Success
             True = Fail
-        """
-        
+        """        
         start_status=self.status(outlet)
+        if start_status == 'Off':
+          return False
         if start_status != 'Unknown':
           self.off(outlet)
           time.sleep(CYCLETIME)
